Les Fake News et leur pouvoir de sculpter la réalité - Christophe MICHEL

Hygiène Mentale

Les Fake News et leur pouvoir de sculpter la réalité - Christophe MICHEL

J'ai eu la chance de pouvoir participer à un congrès au parlement européen à Bruxelles à propos de la désinformation.
"FakeNews as reality shapers" fevrier 2017
La vidéo complete est disponible ici :
http://web.events.streamovations.be/index.php/event/stream/fake-news-in-social-media-as-reality-shapers
J'ai pu y présenter les travaux de Rose Marie Farinella, et défendre mon point de vue sur l'importance de l'Education aux médias à l'école. J'ai également pu passer quelques extraits de mes vidéos. Elles sont toutes disponibles ici
https://www.youtube.com/watch?v=__DVwG9oiuU&list=PL8kpTYGNfAcbVL-wbRm65_YRhols6n2ha
________
Le facebook : http://facebook.com/HygieneMentale
Le twitter : https://twitter.com/HygieneMentale
Le Diaspora* : https://framasphere.org/people/43360ee086750134e9c62a0000053625
Le site : http://laelith.fr/Zet
L'association : http://zetetique.fr
Le Tipee : https://www.tipeee.com/hygiene-mentale

16/03/2017